@@ -1,12 +1,15 @@
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 
 from .container import Container
 from .hashable import Hashable
-from .iterable import Iterable, Iterator
+from .iterable import Iterable, Iterator, Reversible
+from .sized import Sized
 
 __all__ = [
     "Container",
     "Hashable",
     "Iterable",
     "Iterator",
+    "Reversible",
+    "Sized",
 ]
